@@ -1,5 +1,6 @@
 class Collection(object):
     """A generic iterable set of objects."""
+
     class Meta:
         pass
 
@@ -20,10 +21,11 @@ class Collection(object):
         return str(self._objects)
 
     def __repr__(self):  # pragma: no cover
-        return '<{}>'.format(self.__class__.__name__)
+        return "<{}>".format(self.__class__.__name__)
 
     def __bool__(self):
         return bool(self._objects)
+
     __nonzero__ = __bool__
 
     @property
@@ -31,9 +33,9 @@ class Collection(object):
         return self._objects
 
     def append(self, v):
-        object_class = getattr(self.Meta, 'object_class', object)
+        object_class = getattr(self.Meta, "object_class", object)
 
         if not isinstance(v, object_class):
-            raise TypeError('Expected an instance of `{}`.'.format(object_class.__name__))
+            raise TypeError("Expected an instance of `{}`.".format(object_class.__name__))
 
         self._objects.append(v)
